Module syscalls

Module syscalls 

Structs

SyscallAbort
Abort syscall functions, called when the BPF program calls abort() LLVM will insert calls to abort() if it detects an untenable situation, abort() is not intended to be called explicitly by the program. Causes the BPF program to be halted immediately
SyscallAllocFree
Dynamic memory allocation syscall called when the BPF program calls gema_alloc_free_(). The allocator is expected to allocate/free from/to a given chunk of memory and enforce size restrictions. The memory chunk is given to the allocator during allocator creation and information about that memory (start address and size) is passed to the VM to use for enforcement.
SyscallBlake3
SyscallGetReturnData
SyscallInvokeSignedC
Cross-program invocation called from C
SyscallInvokeSignedRust
Cross-program invocation called from Rust
SyscallKeccak256
SyscallLog
Log a user’s info message
SyscallLogBpfComputeUnits
Log current compute consumption
SyscallLogData
SyscallLogPubkey
Log 5 64-bit values
SyscallLogU64
Log 5 64-bit values
SyscallMemcmp
memcmp
SyscallMemcpy
memcpy
SyscallMemmove
memmove
SyscallMemset
memset
SyscallPanic
Panic syscall function, called when the BPF program calls ’gema_panic_()` Causes the BPF program to be halted immediately Log a user’s info message
SyscallSecp256k1Recover
secp256k1_recover
SyscallSetReturnData
SyscallSha256
SHA256

Enums

SyscallError
Error definitions

Constants

MAX_SIGNERS
Maximum signers

Functions

bind_syscall_context_objects
register_syscalls